@@ -9,20 +9,21 @@
 
 #include "eventviews_export.h"
 
-#include <AkonadiCore/Item>
 #include <Akonadi/Calendar/ETMCalendar>
+#include <AkonadiCore/Item>
 #include <KCalendarCore/Incidence>
 
 #include <QColor>
 #include <QList>
 
-namespace EventViews {
+namespace EventViews
+{
 class AgendaView;
 
 class EVENTVIEWS_EXPORT ViewCalendar
 {
 public:
-    typedef QSharedPointer<ViewCalendar> Ptr;
+    using Ptr = QSharedPointer<ViewCalendar>;
 
     virtual ~ViewCalendar();
     virtual bool isValid(const KCalendarCore::Incidence::Ptr &incidence) const = 0;
@@ -38,7 +39,7 @@ public:
 class AkonadiViewCalendar : public ViewCalendar
 {
 public:
-    typedef QSharedPointer<AkonadiViewCalendar> Ptr;
+    using Ptr = QSharedPointer<AkonadiViewCalendar>;
 
     ~AkonadiViewCalendar() override;
     bool isValid(const KCalendarCore::Incidence::Ptr &incidence) const override;
@@ -59,7 +60,7 @@ public:
 class MultiViewCalendar : public ViewCalendar
 {
 public:
-    typedef QSharedPointer<MultiViewCalendar> Ptr;
+    using Ptr = QSharedPointer<MultiViewCalendar>;
 
     ~MultiViewCalendar() override;
     ViewCalendar::Ptr findCalendar(const KCalendarCore::Incidence::Ptr &incidence) const;
