@@ -7,12 +7,12 @@
 */
 #include "multiagendaview.h"
 
-#include "prefs.h"
 #include "agenda/agenda.h"
 #include "agenda/agendaview.h"
 #include "agenda/timelabelszone.h"
-#include "configdialoginterface.h"
 #include "calendarview_debug.h"
+#include "configdialoginterface.h"
+#include "prefs.h"
 
 #include <AkonadiCore/EntityTreeModel>
 #include <AkonadiWidgets/ETMViewStateSaver>
@@ -83,7 +83,8 @@ private:
     class ElidedLabel : public QFrame
     {
     public:
-        ElidedLabel(const QString &text) : mText(text)
+        ElidedLabel(const QString &text)
+            : mText(text)
         {
         }
 
@@ -134,25 +135,25 @@ public:
     int mCustomNumberOfColumns = 2;
     QLabel *mLabel = nullptr;
     QWidget *mRightDummyWidget = nullptr;
-    QHash<QString, KViewStateMaintainer<ETMViewStateSaver> * > mSelectionSavers;
+    QHash<QString, KViewStateMaintainer<ETMViewStateSaver> *> mSelectionSavers;
 };
 
 MultiAgendaView::MultiAgendaView(QWidget *parent)
     : EventView(parent)
     , d(new Private(this))
 {
-    auto *topLevelLayout = new QHBoxLayout(this);
+    auto topLevelLayout = new QHBoxLayout(this);
     topLevelLayout->setSpacing(0);
     topLevelLayout->setContentsMargins(0, 0, 0, 0);
 
     QFontMetrics fm(font());
     int topLabelHeight = 2 * fm.height() + fm.lineSpacing();
 
-    QWidget *topSideBox = new QWidget(this);
-    auto *topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
+    auto topSideBox = new QWidget(this);
+    auto topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
     topSideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
-    QWidget *topSideSpacer = new QWidget(topSideBox);
+    auto topSideSpacer = new QWidget(topSideBox);
     topSideBoxVBoxLayout->addWidget(topSideSpacer);
     topSideSpacer->setFixedHeight(topLabelHeight);
 
@@ -163,17 +164,17 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     d->mLabel->setWordWrap(true);
 
-    QWidget *sideBox = new QWidget(d->mLeftSplitter);
-    auto *sideBoxVBoxLayout = new QVBoxLayout(sideBox);
+    auto sideBox = new QWidget(d->mLeftSplitter);
+    auto sideBoxVBoxLayout = new QVBoxLayout(sideBox);
     sideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     // compensate for the frame the agenda views but not the timelabels have
-    QWidget *timeLabelTopAlignmentSpacer = new QWidget(sideBox);
+    auto timeLabelTopAlignmentSpacer = new QWidget(sideBox);
     sideBoxVBoxLayout->addWidget(timeLabelTopAlignmentSpacer);
 
     d->mTimeLabelsZone = new TimeLabelsZone(sideBox, PrefsPtr(new Prefs()));
 
-    QWidget *timeLabelBotAlignmentSpacer = new QWidget(sideBox);
+    auto timeLabelBotAlignmentSpacer = new QWidget(sideBox);
     sideBoxVBoxLayout->addWidget(timeLabelBotAlignmentSpacer);
 
     d->mLeftBottomSpacer = new QWidget(topSideBox);
@@ -195,7 +196,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mScrollArea->setFrameShape(QFrame::NoFrame);
     topLevelLayout->addWidget(d->mScrollArea, 100);
     d->mTopBox = new QWidget(d->mScrollArea->viewport());
-    auto *mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
+    auto mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
     mTopBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mScrollArea->setWidget(d->mTopBox);
 
@@ -229,12 +230,9 @@ void MultiAgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
         proxy->setSourceModel(calendar->entityTreeModel());
     }
 
-    disconnect(nullptr,
-               SIGNAL(selectionChanged(Akonadi::Collection::List,Akonadi::Collection::List)),
-               this, SLOT(forceRecreateViews()));
+    disconnect(nullptr, SIGNAL(selectionChanged(Akonadi::Collection::List, Akonadi::Collection::List)), this, SLOT(forceRecreateViews()));
 
-    connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged,
-            this, &MultiAgendaView::forceRecreateViews);
+    connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged, this, &MultiAgendaView::forceRecreateViews);
 
     recreateViews();
 }
@@ -272,10 +270,8 @@ void MultiAgendaView::recreateViews()
     d->mTimeLabelsZone->updateAll();
 
     QScrollArea *timeLabel = d->mTimeLabelsZone->timeLabels().at(0);
-    connect(timeLabel->verticalScrollBar(), &QAbstractSlider::valueChanged,
-            d->mScrollBar, &QAbstractSlider::setValue);
-    connect(d->mScrollBar, &QAbstractSlider::valueChanged,
-            timeLabel->verticalScrollBar(), &QAbstractSlider::setValue);
+    connect(timeLabel->verticalScrollBar(), &QAbstractSlider::valueChanged, d->mScrollBar, &QAbstractSlider::setValue);
+    connect(d->mScrollBar, &QAbstractSlider::valueChanged, timeLabel->verticalScrollBar(), &QAbstractSlider::setValue);
 
     resizeSplitters();
     QTimer::singleShot(0, this, &MultiAgendaView::setupScrollBar);
@@ -308,59 +304,37 @@ void MultiAgendaView::Private::deleteViews()
 void MultiAgendaView::Private::setupViews()
 {
     for (AgendaView *agenda : qAsConst(mAgendaViews)) {
-        q->connect(agenda, SIGNAL(newEventSignal()),
-                   q, SIGNAL(newEventSignal()));
-        q->connect(agenda, SIGNAL(newEventSignal(QDate)),
-                   q, SIGNAL(newEventSignal(QDate)));
-        q->connect(agenda, SIGNAL(newEventSignal(QDateTime)),
-                   q, SIGNAL(newEventSignal(QDateTime)));
-        q->connect(agenda,
-                   SIGNAL(newEventSignal(QDateTime,QDateTime)),
-                   q, SIGNAL(newEventSignal(QDateTime,QDateTime)));
+        q->connect(agenda, SIGNAL(newEventSignal()), q, SIGNAL(newEventSignal()));
+        q->connect(agenda, SIGNAL(newEventSignal(QDate)), q, SIGNAL(newEventSignal(QDate)));
+        q->connect(agenda, SIGNAL(newEventSignal(QDateTime)), q, SIGNAL(newEventSignal(QDateTime)));
+        q->connect(agenda, SIGNAL(newEventSignal(QDateTime, QDateTime)), q, SIGNAL(newEventSignal(QDateTime, QDateTime)));
 
-        q->connect(agenda, &EventView::editIncidenceSignal,
-                   q, &EventView::editIncidenceSignal);
-        q->connect(agenda, &EventView::showIncidenceSignal,
-                   q, &EventView::showIncidenceSignal);
-        q->connect(agenda, &EventView::deleteIncidenceSignal,
-                   q, &EventView::deleteIncidenceSignal);
+        q->connect(agenda, &EventView::editIncidenceSignal, q, &EventView::editIncidenceSignal);
+        q->connect(agenda, &EventView::showIncidenceSignal, q, &EventView::showIncidenceSignal);
+        q->connect(agenda, &EventView::deleteIncidenceSignal, q, &EventView::deleteIncidenceSignal);
 
-        q->connect(agenda, &EventView::incidenceSelected,
-                   q, &EventView::incidenceSelected);
+        q->connect(agenda, &EventView::incidenceSelected, q, &EventView::incidenceSelected);
 
-        q->connect(agenda, &EventView::cutIncidenceSignal,
-                   q, &EventView::cutIncidenceSignal);
-        q->connect(agenda, &EventView::copyIncidenceSignal,
-                   q, &EventView::copyIncidenceSignal);
-        q->connect(agenda, &EventView::pasteIncidenceSignal,
-                   q, &EventView::pasteIncidenceSignal);
-        q->connect(agenda, &EventView::toggleAlarmSignal,
-                   q, &EventView::toggleAlarmSignal);
-        q->connect(agenda, &EventView::dissociateOccurrencesSignal,
-                   q, &EventView::dissociateOccurrencesSignal);
+        q->connect(agenda, &EventView::cutIncidenceSignal, q, &EventView::cutIncidenceSignal);
+        q->connect(agenda, &EventView::copyIncidenceSignal, q, &EventView::copyIncidenceSignal);
+        q->connect(agenda, &EventView::pasteIncidenceSignal, q, &EventView::pasteIncidenceSignal);
+        q->connect(agenda, &EventView::toggleAlarmSignal, q, &EventView::toggleAlarmSignal);
+        q->connect(agenda, &EventView::dissociateOccurrencesSignal, q, &EventView::dissociateOccurrencesSignal);
 
-        q->connect(agenda, &EventView::newTodoSignal,
-                   q, &EventView::newTodoSignal);
+        q->connect(agenda, &EventView::newTodoSignal, q, &EventView::newTodoSignal);
 
-        q->connect(agenda, &EventView::incidenceSelected,
-                   q, &MultiAgendaView::slotSelectionChanged);
+        q->connect(agenda, &EventView::incidenceSelected, q, &MultiAgendaView::slotSelectionChanged);
 
-        q->connect(agenda, &AgendaView::timeSpanSelectionChanged,
-                   q, &MultiAgendaView::slotClearTimeSpanSelection);
+        q->connect(agenda, &AgendaView::timeSpanSelectionChanged, q, &MultiAgendaView::slotClearTimeSpanSelection);
 
-        q->disconnect(agenda->agenda(),
-                      SIGNAL(zoomView(int,QPoint,Qt::Orientation)),
-                      agenda, nullptr);
-        q->connect(agenda->agenda(),
-                   &Agenda::zoomView,
-                   q, &MultiAgendaView::zoomView);
+        q->disconnect(agenda->agenda(), SIGNAL(zoomView(int, QPoint, Qt::Orientation)), agenda, nullptr);
+        q->connect(agenda->agenda(), &Agenda::zoomView, q, &MultiAgendaView::zoomView);
     }
 
     AgendaView *lastView = mAgendaViews.last();
     for (AgendaView *agenda : qAsConst(mAgendaViews)) {
         if (agenda != lastView) {
-            connect(agenda->agenda()->verticalScrollBar(), &QAbstractSlider::valueChanged,
-                    lastView->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
+            connect(agenda->agenda()->verticalScrollBar(), &QAbstractSlider::valueChanged, lastView->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
         }
     }
 
@@ -402,7 +376,7 @@ int MultiAgendaView::currentDateCount() const
 
 void MultiAgendaView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
 {
-    Q_UNUSED(preferredMonth);
+    Q_UNUSED(preferredMonth)
     d->mStartDate = start;
     d->mEndDate = end;
     slotResizeScrollView();
@@ -466,16 +440,12 @@ void MultiAgendaView::slotClearTimeSpanSelection()
 
 AgendaView *MultiAgendaView::Private::createView(const QString &title)
 {
-    QWidget *box = new QWidget(mTopBox);
+    auto box = new QWidget(mTopBox);
     mTopBox->layout()->addWidget(box);
-    auto *layout = new QVBoxLayout(box);
+    auto layout = new QVBoxLayout(box);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(new ElidedLabel(title));
-    AgendaView *av = new AgendaView(q->preferences(),
-                                    q->startDateTime().date(),
-                                    q->endDateTime().date(),
-                                    true,
-                                    true, q);
+    auto av = new AgendaView(q->preferences(), q->startDateTime().date(), q->endDateTime().date(), true, true, q);
     layout->addWidget(av);
     av->setCalendar(q->calendar());
     av->setIncidenceChanger(q->changer());
@@ -485,16 +455,12 @@ AgendaView *MultiAgendaView::Private::createView(const QString &title)
     box->show();
     mTimeLabelsZone->setAgendaView(av);
 
-    q->connect(mScrollBar, &QAbstractSlider::valueChanged,
-               av->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
+    q->connect(mScrollBar, &QAbstractSlider::valueChanged, av->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
 
-    q->connect(av->splitter(), &QSplitter::splitterMoved,
-               q, &MultiAgendaView::resizeSplitters);
-    q->connect(av, &AgendaView::showIncidencePopupSignal,
-               q, &MultiAgendaView::showIncidencePopupSignal);
+    q->connect(av->splitter(), &QSplitter::splitterMoved, q, &MultiAgendaView::resizeSplitters);
+    q->connect(av, &AgendaView::showIncidencePopupSignal, q, &MultiAgendaView::showIncidencePopupSignal);
 
-    q->connect(av, &AgendaView::showNewEventPopupSignal,
-               q, &MultiAgendaView::showNewEventPopupSignal);
+    q->connect(av, &AgendaView::showNewEventPopupSignal, q, &MultiAgendaView::showNewEventPopupSignal);
 
     const QSize minHint = av->allDayAgenda()->scrollArea()->minimumSizeHint();
 
@@ -574,7 +540,7 @@ void MultiAgendaView::resizeSplitters()
         return;
     }
 
-    auto *lastMovedSplitter = qobject_cast<QSplitter *>(sender());
+    auto lastMovedSplitter = qobject_cast<QSplitter *>(sender());
     if (!lastMovedSplitter) {
         lastMovedSplitter = d->mLeftSplitter;
     }
@@ -688,31 +654,28 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
         d->mCollectionSelectionModels.resize(d->mCustomNumberOfColumns);
         for (int i = 0; i < d->mCustomNumberOfColumns; ++i) {
             // Sort the calanders by name
-            auto *sortProxy = new QSortFilterProxyModel(this);
+            auto sortProxy = new QSortFilterProxyModel(this);
             sortProxy->setDynamicSortFilter(true);
 
             sortProxy->setSourceModel(calendar()->entityTreeModel());
 
             // Only show the first column
-            auto *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
-            columnFilterProxy->setSourceColumns(
-                QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
+            auto columnFilterProxy = new KRearrangeColumnsProxyModel(this);
+            columnFilterProxy->setSourceColumns(QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
 
             // Keep track of selection.
-            auto *qsm = new QItemSelectionModel(columnFilterProxy);
+            auto qsm = new QItemSelectionModel(columnFilterProxy);
 
             // Make the model checkable.
-            auto *checkableProxy = new KCheckableProxyModel(this);
+            auto checkableProxy = new KCheckableProxyModel(this);
             checkableProxy->setSourceModel(columnFilterProxy);
             checkableProxy->setSelectionModel(qsm);
-            const QString groupName
-                = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
+            const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
             const KConfigGroup group = configGroup.config()->group(groupName);
 
             if (!d->mSelectionSavers.contains(groupName)) {
-                d->mSelectionSavers.insert(groupName,
-                                           new KViewStateMaintainer<ETMViewStateSaver>(group));
+                d->mSelectionSavers.insert(groupName, new KViewStateMaintainer<ETMViewStateSaver>(group));
                 d->mSelectionSavers[groupName]->setSelectionModel(checkableProxy->selectionModel());
             }
 
@@ -733,15 +696,13 @@ void MultiAgendaView::doSaveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("ColumnTitles", d->mCustomColumnTitles);
     int idx = 0;
     for (KCheckableProxyModel *checkableProxyModel : qAsConst(d->mCollectionSelectionModels)) {
-        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(
-            idx);
+        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(idx);
         KConfigGroup group = configGroup.config()->group(groupName);
         ++idx;
-        //TODO never used ?
+        // TODO never used ?
         KViewStateMaintainer<ETMViewStateSaver> saver(group);
         if (!d->mSelectionSavers.contains(groupName)) {
-            d->mSelectionSavers.insert(groupName,
-                                       new KViewStateMaintainer<ETMViewStateSaver>(group));
+            d->mSelectionSavers.insert(groupName, new KViewStateMaintainer<ETMViewStateSaver>(group));
             d->mSelectionSavers[groupName]->setSelectionModel(checkableProxyModel->selectionModel());
         }
         d->mSelectionSavers[groupName]->saveState();
