@@ -1,28 +1,12 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef CALENDARVIEWS_TODOVIEW_H
 #define CALENDARVIEWS_TODOVIEW_H
@@ -41,11 +25,13 @@ class TodoViewQuickSearch;
 class TodoViewSortFilterProxyModel;
 class TodoViewView;
 
-namespace KPIM {
+namespace CalendarSupport
+{
 class KDatePickerPopup;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ETMViewStateSaver;
 }
 
@@ -55,7 +41,15 @@ class QModelIndex;
 class QToolButton;
 class QTimer;
 
-namespace EventViews {
+namespace EventViews
+{
+/**
+ * This class provides a view for Todo items.
+
+ * @short View for Todo components.
+ * @author Cornelius Schumacher <schumacher@kde.org>, Reinhold Kainhofer <reinhold@kainhofer.com>
+ * @see EventView
+ */
 class EVENTVIEWS_EXPORT TodoView : public EventViews::EventView
 {
     Q_OBJECT
@@ -167,8 +161,8 @@ private:
     QToolButton *mFlatViewButton = nullptr;
 
     QMenu *mItemPopupMenu = nullptr;
-    KPIM::KDatePickerPopup *mCopyPopupMenu = nullptr;
-    KPIM::KDatePickerPopup *mMovePopupMenu = nullptr;
+    CalendarSupport::KDatePickerPopup *mCopyPopupMenu = nullptr;
+    CalendarSupport::KDatePickerPopup *mMovePopupMenu = nullptr;
     QMenu *mPriorityPopupMenu = nullptr;
     QMenu *mPercentageCompletedPopupMenu = nullptr;
     QList<QAction *> mItemPopupMenuItemOnlyEntries;
